//
//  Untitled.swift
//  AIRingtone
//
//  Created by 100Years on 2025/3/13.
//

import JXSegmentedView
import JXPagingView

class TSTutorialPopupVC: TSBaseVC {
    
    var tableHeaderViewHeight: CGFloat = 0.0
    var headerInSectionHeight: Int = 44
    let titles:[String] = ["Contact Poster".localized,"Contact Photo".localized]
    let popupContentViewW:CGFloat = k_ScreenWidth - 40.0
    let popupContentViewH:CGFloat = k_ScreenHeight - 268.0
    
    lazy var popupContentView: UIView = {
        let popupContentView = UIView()
        popupContentView.backgroundColor = .cardColor
        popupContentView.cornerRadius = 20.0
        return popupContentView
    }()
    
    lazy var segmentedDataSource: JXSegmentedTitleDataSource = {
        let dataSource = JXSegmentedTitleDataSource()
        dataSource.isTitleColorGradientEnabled = true
        dataSource.itemSpacing = 16
        dataSource.itemWidthIncrement = 32
        
        dataSource.isItemSpacingAverageEnabled = false
        dataSource.titles = titles
        dataSource.titleNormalColor = .assist
        dataSource.titleSelectedColor = .white
        dataSource.titleNormalFont = .font(size: 16.0)
        return dataSource
    }()
    
    //配置指示器
    lazy var indicator: JXSegmentedIndicatorBackgroundView = {
        let indicator = JXSegmentedIndicatorBackgroundView()
        indicator.isIndicatorConvertToItemFrameEnabled = true
        indicator.isIndicatorConvertToItemFrameEnabled = true
        indicator.indicatorHeight = 2
        indicator.indicatorPosition = .bottom
        
        let gradientView = JXSegmentedComponetGradientView()
        gradientView.gradientLayer.endPoint = CGPoint(x: 0, y: 1)
        gradientView.gradientLayer.endPoint = CGPoint(x: 1, y: 1)
        gradientView.gradientLayer.colors = ["#E961F6".uiColor.cgColor, "#7E57F4".uiColor.cgColor]
        gradientView.autoresizingMask = [.flexibleWidth, .flexibleHeight]
        gradientView.cornerRadius = 1
        indicator.addSubview(gradientView)
        indicator.addSubview(gradientView)
        
        return indicator
    }()
    

    lazy var segmentedView: JXSegmentedView = {
        let segmentedView = JXSegmentedView(frame: CGRect(x: 0, y: 0, width: popupContentViewW, height: CGFloat(headerInSectionHeight)))
        segmentedView.indicators = [indicator]
        segmentedView.dataSource = segmentedDataSource
        segmentedView.backgroundColor = .clear
        segmentedView.contentEdgeInsetLeft = 26
        segmentedView.listContainer = pagingView.listContainerView
        return segmentedView
    }()
    
    lazy var pagingView: JXPagingView = {
        let pagingView = JXPagingView(delegate: self)
        pagingView.mainTableView.backgroundColor = .clear
        pagingView.frame = CGRect(x: 0, y: 0, width:popupContentViewW, height:popupContentViewH)
        pagingView.listContainerView.listCellBackgroundColor = .clear
        //扣边返回处理，下面的代码要加上
        pagingView.listContainerView.scrollView.panGestureRecognizer.require(toFail: self.navigationController!.interactivePopGestureRecognizer!)
        pagingView.mainTableView.panGestureRecognizer.require(toFail: self.navigationController!.interactivePopGestureRecognizer!)
        pagingView.pinSectionHeaderVerticalOffset = Int(TSTGPTitleView.viewH)
        return pagingView
    }()
    
    override func createView() {
    
        setNavBarViewHidden(true)
        view.backgroundColor = .black.withAlphaComponent(0.7)
        
        
        view.addGestureRecognizer(UITapGestureRecognizer(target: self, action: #selector(clickView)))
        
        contentView.addSubview(popupContentView)
        popupContentView.snp.makeConstraints { make in
            make.center.equalToSuperview()
            make.width.equalTo(popupContentViewW)
            make.height.equalTo(popupContentViewH)
        }
        createSegmentedView()
    }
    
    @objc func clickView() {
        self.dismiss()
    }
}

extension TSTutorialPopupVC {
    
    func createSegmentedView(){
        popupContentView.addSubview(segmentedView)
        popupContentView.addSubview(pagingView)
    }
}
extension TSTutorialPopupVC: JXPagingViewDelegate {

    func tableHeaderViewHeight(in pagingView: JXPagingView) -> Int {
        return Int(tableHeaderViewHeight)
    }

    func tableHeaderView(in pagingView: JXPagingView) -> UIView {
        return UIView()
    }

    func heightForPinSectionHeader(in pagingView: JXPagingView) -> Int {
        return headerInSectionHeight
    }

    func viewForPinSectionHeader(in pagingView: JXPagingView) -> UIView {
        return segmentedView
    }

    func numberOfLists(in pagingView: JXPagingView) -> Int {
        return titles.count
    }

    func pagingView(_ pagingView: JXPagingView, initListAtIndex index: Int) -> JXPagingViewListViewDelegate {
        return TSTutorialPopupView()
    }
}


@objc public class TSTutorialPopupView: TSBaseView {
    
    var listViewDidScrollCallback: ((UIScrollView) -> ())?
    lazy var stackView: TSCustomStackView = {
        let stackView = TSCustomStackView()
        stackView.scrollView.delegate = self
        return stackView
    }()
    
    public override func creatUI() {
        self.backgroundColor = .random
        
        contentView.addSubview(stackView)
        stackView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
    }

}

extension TSTutorialPopupView: JXPagingViewListViewDelegate,UIScrollViewDelegate {
    
//    public func scrollViewDidScroll(_ scrollView: UIScrollView) {
//        self.listViewDidScrollCallback?(scrollView)
//    }
    
    public func listScrollView() -> UIScrollView {
        return UIScrollView()
//        return stackView.scrollView
    }
    
    public func listViewDidScrollCallback(callback: @escaping (UIScrollView) -> ()) {
//        self.listViewDidScrollCallback = callback
        callback(UIScrollView())
    }
    
    public func listView() -> UIView {
        return self
    }
    
}
